==> nextcloud-app-deck-1%3a1.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/he.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "יצרת לוח חדש {board}",
    "{user} has created a new board {board}" : "נוצר לוח חדש {board} על ידי {user}",
    "You have deleted the board {board}" : "מחקת את הלוח {board}",
    "{user} has deleted the board {board}" : "הלוח {board} נמחק על ידי {user}",
    "You have restored the board {board}" : "שחזרת את הלוח {board}",
    "{user} has restored the board {board}" : "הלוח {board} שוחזר על ידי {user}",
    "You have shared the board {board} with {acl}" : "שיתפת את הלוח {board} עם {acl}",
    "{user} has shared the board {board} with {acl}" : "הלוח {board} שותף עם {acl} על ידי {user}",
    "You have removed {acl} from the board {board}" : "הסרת את {acl} מהלוח {board}",
    "{user} has removed {acl} from the board {board}" : "בוצעה הסרה של {acl} מהלוח {board} על ידי {user}",
    "You have renamed the board {before} to {board}" : "שינית את שם הלוח {before} לשם {board}",
    "You have commented on card {card}" : "הגבת על הכרטיס {cart}",
    "{user} has commented on card {card}" : "נוספה תגובה מאת {user} על הכרטיס {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
    "Deck" : "חפיסה",
    "Changes in the <strong>Deck app</strong>" : "שינויים ל<strong>יישומון החבילה</strong>",
    "A <strong>comment</strong> was created on a card" : "נוצרה <strong>הערה</strong> על כרטיס",
    "Personal" : "אישי",
    "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
    "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
    "{user} has shared the board %s with you." : "הלוח %s שותף אתך על ידי {user}",
    "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
    "Finished" : "הסתיים",
    "To review" : "לסקירה",
    "Action needed" : "נדרשת פעולה",
    "Later" : "מאוחר יותר",
    "copy" : "עותק",
    "To do" : "לעשות",
    "Doing" : "בביצוע",
    "Done" : "הסתיים",
    "Example Task 3" : "משימה לדוגמה 3",
    "Example Task 2" : "משימה לדוגמה 2",
    "Example Task 1" : "משימה לדוגמה 1",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
    "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
    "Create new board" : "יצירת לוח חדש",
    "new board" : "לוח חדש",
    "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
    "Select board" : "בחירת לוח",
    "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
    "Select a board" : "נא לבחור לוח",
    "Select a card" : "נא לבחור כרטיס",
    "Link to card" : "קישור לכרטיס",
    "Cancel" : "ביטול",
    "File already exists" : "הקובץ כבר קיים",
    "A file with the name {filename} already exists." : "כבר קיים קובץ עם השם {filename}.",
    "Do you want to overwrite it?" : "לשכתב עליו?",
    "Overwrite file" : "דריסת קובץ",
    "Keep existing file" : "לשמור על הקובץ הקיים",
    "This board is read only" : "הלוח הזה הוא לקריאה בלבד",
    "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
    "Archived cards" : "כרטיסים בארכיון",
    "Add new list" : "הוספת רשימה חדשה",
    "List name" : "שם הרשימה",
    "Apply filter" : "החלת מסנן",
    "Filter by tag" : "סינון לפי תגית",
    "Filter by assigned user" : "סינון לפי משתמש מוקצה",
    "Filter by due date" : "סינון לפי תאריך יעד",
    "Overdue" : "באיחור",
    "Next 24 hours" : "ב־24 השעות הבאות",
    "Next 7 days" : "ב־7 הימים הבאים",
    "Next 30 days" : "ב־30 הימים הבאים",
    "No due date" : "ללא תאריך יעד",
    "Show archived cards" : "הצגת כרטיסים בארכיון",
    "Toggle compact mode" : "החלפת מצב חסכוני",
    "Details" : "פרטים",
    "Loading board" : "הלוח נטען",
    "Board not found" : "הלוח לא נמצא",
    "Sharing" : "שיתוף",
    "Tags" : "תגיות",
    "Deleted items" : "פריטים שנמחקו",
    "Timeline" : "ציר זמן",
    "Deleted lists" : "רשימות שנמחקו",
    "Undo" : "ביטול",
    "Deleted cards" : "כרטיסים שנמחקו",
    "Share board with a user, group or circle …" : "שיתוף לוח עם משתמש, קבוצה או מעגל…",
    "Board owner" : "בעלות על הלוח",
    "(Group)" : "(קבוצה)",
    "(Circle)" : "(מעגל)",
    "Can edit" : "ניתן לערוך",
    "Can share" : "Can share",
    "Can manage" : "הרשאת ניהול",
    "Delete" : "מחיקה",
    "Add a new stack" : "הוספת ערימה חדשה",
    "Delete list" : "מחיקת רשימה",
    "Add card" : "הוספת כרטיס",
    "Add a new card" : "הוספת כרטיס חדש",
    "Edit" : "עריכה",
    "Add a new tag" : "הוספת תגית חדשה",
    "title and color value must be provided" : "יש לספק כותרת וערך צבע",
    "Title" : "תפקיד",
    "Members" : "חברים",
    "Add this attachment" : "הוספת קובץ מצורף זה",
    "Delete Attachment" : "מחיקת קובץ מצורף",
    "Restore Attachment" : "שחזור קובץ מצורף",
    "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
    "Assign to users" : "הקצאה למשתמשים",
    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
    "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
    "Due date" : "מועד תפוגה",
    "Set a due date" : "הגדרת תאריך יעד",
    "Remove due date" : "הסרת מועד התפוגה",
    "Description" : "תיאוג",
    "(Unsaved)" : "(לא נשמר)",
    "(Saving…)" : "(מתבצעת שמירה…)",
    "Formatting help" : "עזרה בסידור בתבנית",
    "Add Attachment" : "הוספת קובץ מצורף",
    "Edit description" : "עריכת תיאור",
    "View description" : "הצגת תיאור",
    "Attachments" : "קבצים מצורפים",
    "Comments" : "תגובות",
    "Choose attachment" : "בחירת קובץ מצורף",
    "Modified" : "מועד שינוי",
    "Created" : "מועד היצירה",
    "Upload attachment" : "העלאת קבצים מצורפים",
    "No comments yet. Begin the discussion!" : "אין עדיין הערות. אפשר להתחיל לדון!",
    "Save" : "שמור",
    "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
    "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
    "In reply to" : "בתגובה אל",
    "Reply" : "תגובה",
    "Update" : "עדכון",
    "(group)" : "(קבוצה)",
    "(circle)" : "(מעגל)",
    "seconds ago" : "לפני מספר שניות",
    "Assign to me" : "הקצאה אלי",
    "Delete card" : "מחיקת כרטיס לארכיון",
    "Move card" : "העברת כרטיס",
    "Card details" : "פרטי הכרטיס",
    "Select a stack" : "בחירת ערימה",
    "All boards" : "כל הלוחות",
    "Archived boards" : "לוחות שנשמרו בארכיון",
    "Shared boards" : "לוחות משותפים",
    "Settings" : "הגדרות",
    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
    "New board title" : "כותרת לוח חדשה",
    "Share" : "שיתוף",
    "Options" : "אפשרויות",
    "Edit board" : "עריכת לוח",
    "An error occurred" : "אירעה שגיאה",
    "Clone board" : "שכפול לוח",
    "Archive board" : "העברת לוח לארכיון",
    "Unarchive board" : "הוצאת ארכיון מהלוח",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "למחוק את הלוח {title}? פעולה זו תמחק את כל הנתונים של הלוח הזה.",
    "Delete the board?" : "למחוק את הלוח הזה?",
    "Delete board" : "מחיקת לו",
    "Board details" : "פרטי לוח",
    "Link to a board" : "קישור ללוח",
    "Link to a card" : "קישור לכרטיס",
    "Something went wrong" : "משהו השתבש",
    "Maximum file size of {size} exceeded" : "גודל הקבצים המרבי {size} הושג"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-deck-1%3a1.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/he.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "יצרת לוח חדש {board}",
    "{user} has created a new board {board}" : "נוצר לוח חדש {board} על ידי {user}",
    "You have deleted the board {board}" : "מחקת את הלוח {board}",
    "{user} has deleted the board {board}" : "הלוח {board} נמחק על ידי {user}",
    "You have restored the board {board}" : "שחזרת את הלוח {board}",
    "{user} has restored the board {board}" : "הלוח {board} שוחזר על ידי {user}",
    "You have shared the board {board} with {acl}" : "שיתפת את הלוח {board} עם {acl}",
    "{user} has shared the board {board} with {acl}" : "הלוח {board} שותף עם {acl} על ידי {user}",
    "You have removed {acl} from the board {board}" : "הסרת את {acl} מהלוח {board}",
    "{user} has removed {acl} from the board {board}" : "בוצעה הסרה של {acl} מהלוח {board} על ידי {user}",
    "You have renamed the board {before} to {board}" : "שינית את שם הלוח {before} לשם {board}",
    "{user} has renamed the board {before} to {board}" : "השם של הלוח {before} השתנה לשם {board} על ידי {user}",
    "You have archived the board {board}" : "העברת את הלוח {board} לארכיון",
    "{user} has archived the board {before}" : "הארכיון {before} הועבר לארכיון על ידי {user}",
    "You have unarchived the board {board}" : "הוצאת את הלוח {board} מהארכיון",
    "{user} has unarchived the board {before}" : "הלוח {before} הוצא מהארכיון על ידי {user}",
    "You have removed the due date of card {card}" : "הסרת את מועד היעד מהכרטיס {card}",
    "{user} has removed the due date of card {card}" : "מועד היעד של הכרטיס {card} הוסר על ידי {user}",
    "You have commented on card {card}" : "הגבת על הכרטיס {cart}",
    "{user} has commented on card {card}" : "נוספה תגובה מאת {user} על הכרטיס {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>תיאור של כרטיס</strong> בתוך יישומון החבילה נערך",
    "Deck" : "חפיסה",
    "Changes in the <strong>Deck app</strong>" : "שינויים ל<strong>יישומון החבילה</strong>",
    "A <strong>comment</strong> was created on a card" : "נוצרה <strong>הערה</strong> על כרטיס",
    "Personal" : "אישי",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "הכרטיס \"%s\" שב־„%s” הוקצה אליך על ידי %s.",
    "{user} has assigned the card \"%s\" on \"%s\" to you." : "הכרטיס „%s” שב„%s” הוקצה לך על ידי {user}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "הכרטיס „%s” שתחת „%s” הגיע למועד התפוגה שלו.",
    "%s has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי %s בתגובה על „%s”.",
    "{user} has mentioned you in a comment on \"%s\"." : "אוזכרת על ידי {user} בתגובה על „%s”.",
    "The board \"%s\" has been shared with you by %s." : "הלוח „%s” שותף אתך על ידי %s.",
    "{user} has shared the board %s with you." : "הלוח %s שותף אתך על ידי {user}",
    "No data was provided to create an attachment." : "לא סופקו נתונים ליצירת קובץ מצורף",
    "Finished" : "הסתיים",
    "To review" : "לסקירה",
    "Action needed" : "נדרשת פעולה",
    "Later" : "מאוחר יותר",
    "copy" : "עותק",
    "To do" : "לעשות",
    "Doing" : "בביצוע",
    "Done" : "הסתיים",
    "Example Task 3" : "משימה לדוגמה 3",
    "Example Task 2" : "משימה לדוגמה 2",
    "Example Task 1" : "משימה לדוגמה 1",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
    "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
    "Card details" : "פרטי הכרטיס",
    "Add board" : "הוספת לוח",
    "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
    "Search by board title" : "חיפוש לפי כותרת לו",
    "Select board" : "בחירת לוח",
    "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
    "Select a board" : "נא לבחור לוח",
    "Select a card" : "נא לבחור כרטיס",
    "Link to card" : "קישור לכרטיס",
    "Cancel" : "ביטול",
    "File already exists" : "הקובץ כבר קיים",
    "A file with the name {filename} already exists." : "כבר קיים קובץ עם השם {filename}.",
    "Do you want to overwrite it?" : "לשכתב עליו?",
    "Overwrite file" : "דריסת קובץ",
    "Keep existing file" : "לשמור על הקובץ הקיים",
    "This board is read only" : "הלוח הזה הוא לקריאה בלבד",
    "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
    "Archived cards" : "כרטיסים בארכיון",
    "Add list" : "הוספת רשימה",
    "List name" : "שם הרשימה",
    "Apply filter" : "החלת מסנן",
    "Filter by tag" : "סינון לפי תגית",
    "Filter by assigned user" : "סינון לפי משתמש מוקצה",
    "Filter by due date" : "סינון לפי תאריך יעד",
    "Overdue" : "באיחור",
    "Next 24 hours" : "ב־24 השעות הבאות",
    "Next 7 days" : "ב־7 הימים הבאים",
    "Next 30 days" : "ב־30 הימים הבאים",
    "No due date" : "ללא תאריך יעד",
    "Clear filter" : "מחיקת מסנן",
    "Hide archived cards" : "הסתרת כרטיסים בארכיון",
    "Show archived cards" : "הצגת כרטיסים בארכיון",
    "Toggle compact mode" : "החלפת מצב חסכוני",
    "Details" : "פרטים",
    "Loading board" : "הלוח נטען",
    "Board not found" : "הלוח לא נמצא",
    "Sharing" : "שיתוף",
    "Tags" : "תגיות",
    "Deleted items" : "פריטים שנמחקו",
    "Timeline" : "ציר זמן",
    "Deleted lists" : "רשימות שנמחקו",
    "Undo" : "ביטול",
    "Deleted cards" : "כרטיסים שנמחקו",
    "Share board with a user, group or circle …" : "שיתוף לוח עם משתמש, קבוצה או מעגל…",
    "Board owner" : "בעלות על הלוח",
    "(Group)" : "(קבוצה)",
    "(Circle)" : "(מעגל)",
    "Can edit" : "ניתן לערוך",
    "Can share" : "Can share",
    "Can manage" : "הרשאת ניהול",
    "Delete" : "מחיקה",
    "Delete list" : "מחיקת רשימה",
    "Add card" : "הוספת כרטיס",
    "Add a new card" : "הוספת כרטיס חדש",
    "Edit" : "עריכה",
    "Add a new tag" : "הוספת תגית חדשה",
    "title and color value must be provided" : "יש לספק כותרת וערך צבע",
    "Title" : "תפקיד",
    "Members" : "חברים",
    "Upload attachment" : "העלאת קבצים מצורפים",
    "Add this attachment" : "הוספת קובץ מצורף זה",
    "Delete Attachment" : "מחיקת קובץ מצורף",
    "Restore Attachment" : "שחזור קובץ מצורף",
    "Assign a tag to this card…" : "הקצאת תגית לכרטיס זה…",
    "Assign to users" : "הקצאה למשתמשים",
    "Assign to users/groups/circles" : "הקצאה למשתמשים/קבוצות/מעגלים",
    "Assign a user to this card…" : "הקצאת משתמש לכרטיס זה…",
    "Due date" : "מועד תפוגה",
    "Set a due date" : "הגדרת תאריך יעד",
    "Remove due date" : "הסרת מועד התפוגה",
    "Description" : "תיאוג",
    "(Unsaved)" : "(לא נשמר)",
    "(Saving…)" : "(מתבצעת שמירה…)",
    "Formatting help" : "עזרה בסידור בתבנית",
    "Edit description" : "עריכת תיאור",
    "View description" : "הצגת תיאור",
    "Add Attachment" : "הוספת קובץ מצורף",
    "Attachments" : "קבצים מצורפים",
    "Comments" : "תגובות",
    "Choose attachment" : "בחירת קובץ מצורף",
    "Select Date" : "בחירת תאריך",
    "Modified" : "מועד שינוי",
    "Created" : "מועד היצירה",
    "No comments yet. Begin the discussion!" : "אין עדיין הערות. אפשר להתחיל לדון!",
    "Save" : "שמור",
    "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
    "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
    "In reply to" : "בתגובה אל",
    "Reply" : "תגובה",
    "Update" : "עדכון",
    "(group)" : "(קבוצה)",
    "(circle)" : "(מעגל)",
    "Assign to me" : "הקצאה אלי",
    "Unarchive card" : "הוצאת הכרטיס מהארכיון",
    "Archive card" : "העברת כרטיס לארכיון",
    "Delete card" : "מחיקת כרטיס לארכיון",
    "Move card" : "העברת כרטיס",
    "Move card to another board" : "העברת כרטיס ללוח אחר",
    "seconds ago" : "לפני מספר שניות",
    "All boards" : "כל הלוחות",
    "Archived boards" : "לוחות שנשמרו בארכיון",
    "Shared with you" : "משותף אתך",
    "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
    "Edit board" : "עריכת לוח",
    "Clone board " : "שכפול לוח",
    "Unarchive board " : "הוצאת הלוח מהארכיון",
    "Archive board " : "העברת הלוח לארכיון",
    "Delete board " : "מחיקת לוח",
    "Board details" : "פרטי לוח",
    "Board {0} deleted" : "הלוח {0} נמחק",
    "An error occurred" : "אירעה שגיאה",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "למחוק את הלוח {title}? פעולה זו תמחק את כל הנתונים של הלוח הזה.",
    "Delete the board?" : "למחוק את הלוח הזה?",
    "Today" : "היום",
    "Tomorrow" : "מחר",
    "This week" : "השבוע",
    "Link to a board" : "קישור ללוח",
    "Link to a card" : "קישור לכרטיס",
    "Something went wrong" : "משהו השתבש",
    "Maximum file size of {size} exceeded" : "גודל הקבצים המרבי {size} הושג"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
